==> akonadi-22.08.1.tgz: lib/cmake/KF5Akonadi/KF5AkonadiTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::AkonadiPrivate" for configuration "Release"
set_property(TARGET KF5::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiPrivate.so.2.0"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiPrivate.so.2.0"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiPrivate )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKF5AkonadiPrivate.so.2.0" )

# Import target "KF5::AkonadiCore" for configuration "Release"
set_property(TARGET KF5::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Network;Qt5::Widgets;KF5::AkonadiPrivate;KF5::KIOCore;KF5::I18n;KF5::IconThemes;KF5::ConfigCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiCore.so.3.2"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiCore.so.3.2"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiCore )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiCore "${_IMPORT_PREFIX}/lib/libKF5AkonadiCore.so.3.2" )

# Import target "KF5::AkonadiAgentBase" for configuration "Release"
set_property(TARGET KF5::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::AkonadiPrivate;KF5::AkonadiWidgets;KF5::I18n;Qt5::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiAgentBase.so.2.0"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiAgentBase.so.2.0"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiAgentBase )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKF5AkonadiAgentBase.so.2.0" )

# Import target "KF5::AkonadiWidgets" for configuration "Release"
set_property(TARGET KF5::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::KIOCore;KF5::I18n;KF5::IconThemes;KF5::XmlGui;KF5::ItemViews;Qt5::Sql;KF5::AkonadiPrivate;KF5::WindowSystem"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiWidgets.so.2.1"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiWidgets.so.2.1"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiWidgets )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKF5AkonadiWidgets.so.2.1" )

# Import target "KF5::AkonadiXml" for configuration "Release"
set_property(TARGET KF5::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiXml.so.1.0"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiXml.so.1.0"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiXml )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiXml "${_IMPORT_PREFIX}/lib/libKF5AkonadiXml.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> akonadi-22.12.3.tgz: lib/cmake/KF5Akonadi/KF5AkonadiTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::AkonadiPrivate" for configuration "Release"
set_property(TARGET KF5::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiPrivate PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiPrivate.so.2.0"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiPrivate.so.2.0"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiPrivate )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKF5AkonadiPrivate.so.2.0" )

# Import target "KF5::AkonadiCore" for configuration "Release"
set_property(TARGET KF5::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::AkonadiPrivate;KF5::KIOCore;KF5::I18n;KF5::IconThemes;KF5::ConfigCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiCore.so.3.2"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiCore.so.3.2"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiCore )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiCore "${_IMPORT_PREFIX}/lib/libKF5AkonadiCore.so.3.2" )

# Import target "KF5::AkonadiAgentBase" for configuration "Release"
set_property(TARGET KF5::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::AkonadiPrivate;KF5::AkonadiWidgets;KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiAgentBase.so.2.0"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiAgentBase.so.2.0"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiAgentBase )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKF5AkonadiAgentBase.so.2.0" )

# Import target "KF5::AkonadiWidgets" for configuration "Release"
set_property(TARGET KF5::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::KIOCore;KF5::I18n;KF5::IconThemes;KF5::XmlGui;KF5::ItemViews;KF5::AkonadiPrivate;KF5::WindowSystem"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiWidgets.so.2.1"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiWidgets.so.2.1"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiWidgets )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKF5AkonadiWidgets.so.2.1" )

# Import target "KF5::AkonadiXml" for configuration "Release"
set_property(TARGET KF5::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5AkonadiXml.so.1.0"
  IMPORTED_SONAME_RELEASE "libKF5AkonadiXml.so.1.0"
  )

list(APPEND _cmake_import_check_targets KF5::AkonadiXml )
list(APPEND _cmake_import_check_files_for_KF5::AkonadiXml "${_IMPORT_PREFIX}/lib/libKF5AkonadiXml.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
